function [G] = cdf_NL(alpha,beta,nu,tau,y)
% Evaluation at y of the Normal Laplace cumulative distribution function
%
% INPUT y = data generated from a Normal Laplace distribution (X = exp(Y)
%           is the dPlN)
%       alpha,beta,nu,tau = parameters of the model
%
% OUTPUT G = cdf of the NL distribution (see Reed and Jorgensen, 2004)
%
%
a= alpha/(alpha+beta);
b = beta/(alpha+beta);
e1= exp(  -alpha*y+.5*(alpha^2)*(tau^2) + alpha*nu) ;
e2= exp(beta*y+.5*(beta^2)*(tau^2) - beta*nu);
G = normcdf((y-nu)/tau) - b*e1.*normcdf ((y-nu-alpha*tau^2)/tau) + a*e2.*...
    (1-normcdf ((y-nu+beta*tau^2)/tau));