function [g] = pdf_NL(alpha,beta,nu,tau,y)

% Evaluation at y of the Normal Laplace density function
% 
% INPUT y = data generated from a Normal Laplace distribution (X = exp(Y)
%           is the dPlN)
%       alpha,beta,nu,tau = parameters of the model
%
% OUTPUT g = pdf of the NL distribution (see Reed and Jorgensen, 2004)
%        beta = sampled value of beta at each iteration
%        nu =  sampled value of nu at each iteration
%        tau = sampled value of tau at each iteration
%
g = zeros(1,length(y));
U = (y-nu)/tau;
p = alpha*tau - U;
q = beta*tau + U;
a = (1-normcdf(p)).*normpdf(q) + (1-normcdf(q)).*normpdf(p);
b = all(a); 

if  b == 1
    M = log (a)+.5*(log(2*pi)+p.^2) + .5*(log(2*pi)+q.^2);
    lg = log(alpha)+log(beta)-log(alpha+beta)-.5*(log(2*pi)+U.^2)+ M;
    g = exp(lg);
else
    [i]=find(a~=0);
    [j]=find(a==0);
    M(i) = log (a(i))+.5*(log(2*pi)+p(i).^2) + .5*(log(2*pi)+q(i).^2);
    lg(i) = log(alpha)+log(beta)-log(alpha+beta)-.5*(log(2*pi)+U(i).^2)+ M(i);
    g(i) = exp(lg(i));
    g(j) = 0;
end





