function [r0] = root(data, mu, alpha, beta, nu, tau, N)
%
% Find the value of r0 that solves equation (7) in Ramirez et al.
%
% INPUT data = data generated from a dPlN distribution
%       alpha,beta,nu,tau = parameters of the model
%       N = number of TAM samples. Default N = 100
%
% OUTPUT r0 = Solution to equation (7) in Ramirez et al.
%
% EXAMPLE: alpha = 2; beta = .5; nu = 0; tau = 1;
%          [y] = simulation(alpha,beta,nu,tau,1000);
%          data = exp(y); N = 100; mu = 10;     
%          [r0] = root(data, mu, alpha, beta, nu, tau, N)

[t,w] = TAMsamples(data, alpha, beta, nu, tau, N);

r_dom = 0:.001:1;
for i = 1:length(r_dom)
    y(i) = sum(w.*exp(-mu*(1-r_dom(i)).*t )) - r_dom(i);
end
[i] = find(y<0);
if isempty(i)==1
    r_dom2 = 0.98:.00001:1;
else   
    r_dom2 = r_dom(i(1)-1):.0001:r_dom(i(1));
end
for i = 1:length(r_dom2)
    y2(i) = sum(w.*exp(-mu*(1-r_dom2(i)).*t )) - r_dom2(i);
end
[i] = find(y2<0);
if isempty(i)==1
    r = 1;
else
        r = ( r_dom2(i(1)-1) + r_dom2(i(1)) )/2;
end

r0 = r;